package model

// WorkInstance 工单数据模型
type WorkInstance struct {
	Model
	ModelTenant
	OrderNo     string               `gorm:"column:order_no;type:varchar(30);default:null;comment:工单单号" json:"order_no"`
	Kind        int                  `gorm:"column:kind;type:tinyint(1);default:0;comment:工单类型" json:"kind"`
	Title       string               `gorm:"column:title;type:varchar(30);default:null;comment:工单标题" json:"title"`
	MaterialID  uint64               `gorm:"column:material_id;type:int(11);default:0;comment:装备ID" json:"material_id"`
	PlateNumber string               `gorm:"column:plate_number;type:varchar(10);default:null;comment:车牌号" json:"plate_number"`
	Breakdown   string               `gorm:"column:breakdown;type:varchar(150);default:null;comment:故障" json:"breakdown"`
	Priority    WorkInstancePriority `gorm:"column:priority;type:tinyint(1);default:1;comment:工单优先级" json:"priority"`
	Progress    int                  `gorm:"column:progress;type:tinyint(1);default:1;comment:工单进度" json:"progress"`
	Status      WorkInstanceStatus   `gorm:"column:status;type:tinyint(1);default:0;comment:工单状态" json:"status"`
	Remark      string               `gorm:"column:remark;type:varchar(255);default:null;comment:备注信息" json:"remark"`
	ModelDeleted
	ModelAt
}

// WorkInstanceKind 工单类型
type WorkInstanceKind int

const (
	// WorkInstanceKindForOutside 外修
	WorkInstanceKindForOutside WorkInstanceKind = iota + 1
	// WorkInstanceKindForWithin 内修
	WorkInstanceKindForWithin
)

// WorkInstancePriority 工单优先级
type WorkInstancePriority int

const (
	// WorkInstancePriorityForCommonly 一般
	WorkInstancePriorityForCommonly WorkInstancePriority = iota + 1
	// WorkInstancePriorityForUrgent 紧急
	WorkInstancePriorityForUrgent
	// WorkInstancePriorityForVeryUrgent 非常紧急
	WorkInstancePriorityForVeryUrgent
)

// WorkInstanceStatus 工单状态
type WorkInstanceStatus int

const (
	// WorkInstanceStatusForOngoing 进行中
	WorkInstanceStatusForOngoing WorkInstanceStatus = iota
	// WorkInstanceStatusForComplete 已完成
	WorkInstanceStatusForComplete
)

func (m *WorkInstance) TableName() string {
	return "work_instance"
}

func NewWorkInstance() *WorkInstance {
	return &WorkInstance{}
}
